@@ -18,8 +18,5 @@
 # You should have received a copy of the GNU General Public License
 # along with mcctl. If not, see <http://www.gnu.org/licenses/>.
 
-
-from .__config__ import CFGVARS
-from . import common, config, plugin, proc, service, storage, web
-__all__ = ("CFGVARS", "common", "config", "plugin", "proc", "service", "storage", "web")
-__version__ = "0.4.2"
+ENCODING = "utf-8"
+__version__ = "0.4.3"
