@@ -19,10 +19,14 @@
 # along with mcctl. If not, see <http://www.gnu.org/licenses/>.
 
 import codecs
-import shlex
 import json
+import shlex
+
 from mcstatus import MinecraftServer
-from . import web, storage, plugin, service, status, config, proc, visuals, CFGVARS
+
+from . import (ENCODING, config, plugin, proc, service, status, storage,
+               visuals, web)
+from .__config__ import CFGVARS
 
 
 def create(instance: str, source: str, memory: str, properties: list, literal_url: bool = False, start: bool = False) -> None:
@@ -118,6 +122,11 @@ def collect_server_data(instance: str) -> dict:
     state = get_online_state(unit, status_info.get("proto"))
 
     cmdvars = {k: v for k, v in (x.decode().split("=") for x in unit.Service.Environment)}
+    if envinfo:
+        envinfo_keys = envinfo.keys()
+        for k in cmdvars.keys():
+            if k in envinfo_keys:
+                cmdvars[k] = envinfo[k]
     cmd = " ".join(x.decode() for x in unit.Service.ExecStart[0][1])
     resolved_cmd = cmd.replace("${", "{").format(**cmdvars)
 
@@ -128,7 +137,7 @@ def collect_server_data(instance: str) -> dict:
         type_id = storage.get_type_id(resolved_jar_path)
 
     try:
-        with open(instance_path / "whitelist.json") as wlist_hnd:
+        with open(instance_path / "whitelist.json", encoding=ENCODING) as wlist_hnd:
             whitelist = json.load(wlist_hnd)
     except FileNotFoundError:
         whitelist = None
@@ -155,7 +164,7 @@ def collect_server_data(instance: str) -> dict:
             "main_pid": unit.Service.MainPID,
             "start_command": resolved_cmd,
             "memory_usage": unit.Service.MemoryCurrent,
-            "env": dict(cmdvars),
+            "env": cmdvars,
         },
         "type_id": type_id,
         "config": {
@@ -302,9 +311,10 @@ def configure(instance: str, editor: str, properties: list = None, edit_paths: l
         paths.update({env_path: tmp_path})
 
     if edit_paths:
+        path_keys = paths.keys()
         for file_path in edit_paths:
             # Check if a Temporary File of the Config already exists
-            if file_path not in paths.keys():
+            if file_path not in path_keys:
                 abspath = instance_path / file_path
                 tmp_path = storage.tmpcopy(abspath)
                 proc.edit(tmp_path, editor)
@@ -334,9 +344,9 @@ def mc_status(instance: str) -> None:
         instance (str): The name of the instance.
     """
     data = collect_server_data(instance)
-    properties = data.get("config").get("server.properties")
-    status_info = data.get("status")
-    service_info = data.get("service")
+    properties = data["config"].get("server.properties")
+    status_info = data["status"]
+    service_info = data["service"]
     state = service_info.get('state')
     env = service_info.get('env')
 
