@@ -20,10 +20,11 @@
 
 import os
 import sys
-from typing import Callable, NoReturn
-from pwd import getpwnam
 from contextlib import contextmanager
-from . import CFGVARS
+from pwd import getpwnam
+from typing import Callable, NoReturn
+
+from .__config__ import CFGVARS
 
 
 def set_eids(uid: int, gid: int) -> tuple:
@@ -69,12 +70,11 @@ def elevate(user: str = "root") -> NoReturn:
     desired_uid = getpwnam(user).pw_uid
     if os.getuid() == desired_uid:
         return
-
-    package = sys.modules.get('__main__', {}).__package__
-    if package is None:
-        args = sys.argv
-    else:
+    package = sys.modules['__main__'].__package__  # pylint: disable=no-member
+    if package:
         args = [sys.executable, "-m", package] + sys.argv[1:]
+    else:
+        args = sys.argv
 
     userargs = ["-u", user] if user != 'root' else []
     sudoargs = ["sudo"] + userargs + args
