@@ -19,19 +19,21 @@
 # along with mcctl. If not, see <http:// www.gnu.org/licenses/>.
 
 
-import os
 import gzip
-import shutil
-import random
-import string
 import hashlib
+import os
+import random
+import shutil
+import string
 import tempfile as tmpf
 import zipfile as zf
-from pathlib import Path
 from datetime import datetime
 from grp import getgrgid
+from pathlib import Path
 from pwd import getpwnam
-from . import service, config, visuals, perms, CFGVARS
+
+from . import config, perms, service, visuals
+from .__config__ import CFGVARS
 
 SERVER_USER = CFGVARS.get('system', 'server_user')
 
@@ -378,7 +380,8 @@ def remove_jar(source: str, force: bool = False) -> None:
                 env = {}
             server_jar = instance_path / env.get("JARFILE", "server.jar")
             if get_real_abspath(server_jar) == del_path:
-                raise OSError(f"Type-ID is associated with Instance {instance_path.name}.")
+                raise OSError(
+                    f"Type-ID is associated with Instance {instance_path.name}.")
     else:
         if not del_path.exists():
             raise FileNotFoundError("Cache already cleared.")
